#ifndef FOODDIALOG_H
#define FOODDIALOG_H

#include <QtGui>
#include "xml.h"
#include <QMaemo5ValueButton>
#include <QMaemo5ListPickSelector>

class FoodDialog : public QDialog
{
    Q_OBJECT

public:
    explicit FoodDialog(QWidget *parent = 0);
    void load();

private:
    XML *xml;



    QVBoxLayout *vLayout;

    QStandardItemModel *modelName;
    QStandardItemModel *modelAmount;
    QStandardItemModel*modelType;

    QMaemo5ValueButton *btnName;
    QMaemo5ValueButton *btnAmount;
    QMaemo5ValueButton*btnType;

    QMaemo5ListPickSelector *selectorName;
    QMaemo5ListPickSelector *selectorAmount;
    QMaemo5ListPickSelector *selectorType;
    QPushButton *btnAdd;

private slots:
    void save();
};

#endif // FOODDIALOG_H
